Crate mir_issues

Crate mir_issues 

Structs

Issue
IssueBuffer
Location
Source location: file path and a Unicode code-point span.

Enums

IssueKind
Severity

Functions

psalm_error_level
Psalm error level (1–8) at which name stops being reported as an error. An issue is downgraded to info when the configured level is above this value.